@@ -1,3 +1,5 @@
+# All Rights Reserved.
+#
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
@@ -9,18 +11,7 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-"""compatiblity extensions for SQLAlchemy versions.
 
-Elements within this module provide SQLAlchemy features that have been
-added at some point but for which oslo.db provides a compatible versions
-for previous SQLAlchemy versions.
-
-"""
-from oslo.db.sqlalchemy.compat import handle_error as _h_err
-
-# trying to get: "from oslo.db.sqlalchemy import compat; compat.handle_error"
-# flake8 won't let me import handle_error directly
-handle_error = _h_err.handle_error
-ExceptionContextImpl = _h_err.ExceptionContextImpl
-
-__all__ = ['handle_error', 'ExceptionContextImpl']
+from oslo_db.sqlalchemy.compat import engine_connect  # noqa
+from oslo_db.sqlalchemy.compat import handle_error  # noqa
+from oslo_db.sqlalchemy.compat import utils  # noqa
